==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Modify/Divide/ts/Divide_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Divide</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translatorcomment>--exact match--
--file: LineParallelThrough_pt.ts--
Escolha linha, arco ou círculo</translatorcomment>
        <translation type="obsolete">Escolha linha, arco ou círculo</translation>
    </message>
    <message>
        <location filename="../Divide.js" line="+68"/>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation>Escolha linha, arco, círculo, elipse ou chaveta</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Escolha linha, arco, círculo ou elipse</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Specify point</source>
        <translatorcomment>--exact match--
--file: InfoDistanceEP_pt.ts--
Especifique o ponto</translatorcomment>
        <translation>Especifique o ponto</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Specify second point</source>
        <translation>Indique o segundo ponto</translation>
    </message>
    <message>
        <source>Cutting point is not on entity.</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
Ponto de corte não está na entidade.</translatorcomment>
        <translation type="obsolete">Ponto de corte não está na entidade.</translation>
    </message>
    <message>
        <location filename="../DivideInit.js" line="+2"/>
        <source>&amp;Divide</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Divida</translatorcomment>
        <translation>&amp;Divida</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Modify/Divide/ts/Divide_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Divide</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translatorcomment>--exact match--
--file: LineParallelThrough_pt.ts--
Escolha linha, arco ou círculo</translatorcomment>
        <translation type="obsolete">Escolha linha, arco ou círculo</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Escolha uma linha, arco, círculo, elipse ou spline</translation>
    </message>
    <message>
        <location filename="../Divide.js" line="+66"/>
        <source>Choose line, arc, circle, ellipse, spline or polyline</source>
        <translation>Escolha uma linha, arco, circulo, elipse, spline ou polilinha</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Escolha uma linha, arco, círculo ou elipse</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Specify point</source>
        <translatorcomment>--exact match--
--file: InfoDistanceEP_pt.ts--
Especifique o ponto</translatorcomment>
        <translation>Indique o ponto</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Specify second point</source>
        <translation>Indique o segundo ponto</translation>
    </message>
    <message>
        <source>Cutting point is not on entity.</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
Ponto de corte não está na entidade.</translatorcomment>
        <translation type="obsolete">Ponto de corte não está na entidade.</translation>
    </message>
    <message>
        <location filename="../DivideInit.js" line="+2"/>
        <source>&amp;Divide</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Divida</translatorcomment>
        <translation>&amp;Divida</translation>
    </message>
</context>
</TS>
